@@ -44,19 +44,10 @@ namespace Beagle {
 		// A URI of this Hit's container element
 		private Uri parent_uri = null;
 
-		// File, Web, MailMessage, IMLog, etc.
-		private string type = null;
-
-		// If applicable, otherwise set to null.
-		private string mimeType = null;
-
-		// IndexUser, IndexSystem, Google, Addressbook, iFolder, etc.
-		private string source = null;
-
 		// This is used to hold a copy of the Queryable in the
 		// server-side copy of the Hit.  It is always null
 		// on the client-side.
-		private object sourceObject = null;
+		private object source_object = null;
 
 		// High scores imply greater relevance.
 		private double score = 0.0;
@@ -119,30 +110,34 @@ namespace Beagle {
 			}
 		}
 
-		// DEPRECATED: This is now stored as a property.
-		[XmlAttribute]
+		// File, WebHistory, MailMessage, IMLog, etc.
+		[XmlIgnore]
 		public string Type {
-			get { return type; }
-			set { type = value; }
+			get { return GetFirstProperty ("beagle:HitType"); }
 		}
 
-		// DEPRECATED: This is now stored as a property.
-		[XmlAttribute]
+		// If applicable otherwise can be null.
+		[XmlIgnore]
 		public string MimeType {
-			get { return mimeType; }
-			set { mimeType = value; }
+			get { return GetFirstProperty ("beagle:MimeType"); }
 		}
 	
-		[XmlAttribute]
+		// IndexUser, IndexSystem, Google, Addressbook, iFolder, etc.
+		[XmlIgnore]
 		public string Source {
-			get { return source; }
-			set { source = value; }
+			get { return GetFirstProperty ("beagle:Source"); }
+		}
+
+		// document, archive, image etc.
+		[XmlIgnore]
+		public string FileType {
+			get { return GetFirstProperty ("beagle:FileType"); }
 		}
 
 		[XmlIgnore]
 		public object SourceObject {
-			get { return sourceObject; }
-			set { sourceObject = value; }
+			get { return source_object; }
+			set { source_object = value; }
 		}
 
 		[XmlAttribute]
@@ -236,14 +231,26 @@ namespace Beagle {
 
 		//////////////////////////
 
-		[XmlArray]
-		[XmlArrayItem (ElementName="Property", Type=typeof (Property))]
+		[XmlIgnore]
 		public ArrayList Properties {
 			get {  return properties; }
 		}
 
+		[XmlArray (ElementName="Properties")]
+		[XmlArrayItem (ElementName="Property", Type=typeof (Property))]
+		public PropertyList PropertyList {
+			get { return new PropertyList (properties); }
+			set {
+				foreach (Property prop in value)
+					properties.Add (prop);
+			}
+		}
+
 		public void AddProperty (Property prop)
 		{
+			if (prop == null)
+				return;
+
 			int loc = properties.BinarySearch (prop);
 
 			// If the value is not in the array we get its position
@@ -256,6 +263,9 @@ namespace Beagle {
 
 		public void AddProperty (ICollection props)
 		{
+			if (props == null)
+				return;
+
 			properties.AddRange (props);
 			properties.Sort ();
 		}
@@ -263,12 +273,14 @@ namespace Beagle {
 
 		private bool FindProperty (string key, out int first, out int top)
 		{
-			
 			first = 0;
 			top = 0;
-			int range = properties.Count - 1;
-			Property prop;
 			
+			int range = properties.Count - 1;
+			if (range < 0)
+				return false;
+
+			Property prop;
 			// O(log n + |range|)-time algorithm for 1-d range query
 			while (range > 1) {
 				// find middle index
@@ -320,7 +332,7 @@ namespace Beagle {
 					return null;
 
 				if (top - first != 1) {
-					Logger.Log.Warn ("Accessed multi-property key with Hit's indexer.");
+					Logger.Log.Warn ("Accessed multi-property key '(0}' with Hit's indexer.");
 					return null;
 				}
 
@@ -355,10 +367,11 @@ namespace Beagle {
 		public string GetFirstProperty (string key)
 		{
 			int first, top;
+
 			if (! FindProperty (key, out first, out top))
 				return null;
-			Property prop;
-			prop = properties [first] as Property;
+
+			Property prop = properties [first] as Property;
 			return prop.Value;
 		}
 
@@ -382,6 +395,8 @@ namespace Beagle {
 
 		public override int GetHashCode ()
 		{
+			string type = Type;
+			string source = Source;
 			return (uri != null ? uri.ToString().GetHashCode () : 0)
 				^ (type != null ? type.GetHashCode () : 0)
 				^ (source != null ? source.GetHashCode () : 0);
