@@ -38,7 +38,7 @@
 using System;
 using System.Collections;
 using System.IO;
-using Mono.Data.SqliteClient;
+using Mono.Data.Sqlite;
 
 namespace Beagle.Util {
 
@@ -65,7 +65,7 @@ namespace Beagle.Util {
 		private static string digikamrc = null;
 		private const string tags_sql_string = @"SELECT images.caption, tags.name, tags.pid
 FROM albums, images, imagetags, tags 
-WHERE images.id=imagetags.imageid AND imagetags.tagid=tags.id AND 
+WHERE images.id=imagetags.imageid AND imagetags.tagid=tags.id AND albums.id=images.dirid AND 
 albums.url=@AlbumsUrl AND images.name=@ImagesName";
 		private const string tags_parenttags_sql_string = @"SELECT t1.name, t2.name 
 FROM tags t1, tags t2 
@@ -171,18 +171,26 @@ WHERE t1.pid=t2.id";
 			SqliteCommand command = new SqliteCommand ();
 			command.Connection = Connection;
 			command.CommandText = tags_sql_string;
-			command.Parameters.Add ("@AlbumsUrl", relative_path);
-			command.Parameters.Add ("@ImagesName", filename);
+			command.Parameters.AddWithValue ("@AlbumsUrl", relative_path);
+			command.Parameters.AddWithValue ("@ImagesName", filename);
+			//Console.WriteLine (tags_sql_string);
 			
 			SqliteDataReader reader = command.ExecuteReader ();
+
 			DigikamData imagedata = null;
-			string tag = null;
+			ArrayList original_tags = null;
 			if (reader.Read ()) {
 				imagedata = new DigikamData ();
+				original_tags = new ArrayList ();
 				imagedata.caption = (string) reader [0];
-				tag = ((string) reader [1]);
+				original_tags.Add ((string) reader [1]);
+				//Console.WriteLine ("Adding tag {0}", (string) reader [1]);
 				//Console.WriteLine ("Found caption:" + imagedata.caption);
 			}
+			while (reader.Read ()) {
+				//Console.WriteLine ("Adding more tag {0}", (string) reader [1]);
+				original_tags.Add ((string) reader [1]);
+			}
 
 			reader.Close ();
 			reader = null;
@@ -191,10 +199,18 @@ WHERE t1.pid=t2.id";
 
 			if (imagedata == null)
 				return null;
-			while (tag != null && tag != String.Empty) {
-				//Console.WriteLine ("Found tag: " + tag);
-				imagedata.AddTag (tag);
-				tag = GetParentTag (tag);
+			SortedList s_list = new SortedList ();
+			foreach (string orig_tag in original_tags) {
+				string tag = orig_tag;
+				while ( tag != null && tag != String.Empty) {
+					if (s_list.ContainsKey (tag)) {
+						break;
+					}
+					//Console.WriteLine ("Found tag: " + tag);
+					s_list.Add (tag, null);
+					imagedata.AddTag (tag);
+					tag = GetParentTag (tag);
+				}
 			}
 
 			return imagedata;
